@@ -1,17 +1,26 @@
 from django.views.generic import DetailView, ListView
 
+from podcasting.conf import settings
 from podcasting.models import Episode, Show
 
 
 class ShowListView(ListView):
-    queryset = Show.objects.onsite()
+
+    paginate_by = settings.PODCASTING_PAGINATE_BY
+
+    def get_queryset(self):
+        return Show.objects.onsite()
 
 
 class ShowDetailView(DetailView):
-    queryset = Show.objects.onsite()
+    def get_queryset(self):
+        return Show.objects.onsite()
 
 
 class EpisodeListView(ListView):
+
+    paginate_by = settings.PODCASTING_PAGINATE_BY
+
     def get_queryset(self):
         return Episode.objects.published().filter(show__slug=self.kwargs["show_slug"])
 
